@@ -1,4 +1,4 @@
-// Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
+// Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 // Removes the `__proto__` for security reasons.  This intentionally makes
 // Deno non compliant with ECMA-262 Annex B.2.2.1
 //
@@ -35,6 +35,7 @@ delete Object.prototype.__proto__;
   const timers = window.__bootstrap.timers;
   const base64 = window.__bootstrap.base64;
   const encoding = window.__bootstrap.encoding;
+  const colors = window.__bootstrap.colors;
   const Console = window.__bootstrap.console.Console;
   const worker = window.__bootstrap.worker;
   const internals = window.__bootstrap.internals;
@@ -213,9 +214,6 @@ delete Object.prototype.__proto__;
       runtimeOptions.v8Version,
       runtimeOptions.tsVersion,
     );
-    if (runtimeOptions.unstableFlag) {
-      internals.enableTestSteps();
-    }
     build.setBuildInfo(runtimeOptions.target);
     util.setLogDebug(runtimeOptions.debugFlag, source);
     const prepareStackTrace = core.createPrepareStackTrace(
@@ -574,6 +572,7 @@ delete Object.prototype.__proto__;
       cpuCount,
     } = runtimeOptions;
 
+    colors.setNoColor(noColor);
     if (locationHref != null) {
       location.setLocationHref(locationHref);
     }
@@ -588,7 +587,6 @@ delete Object.prototype.__proto__;
       [internalSymbol]: internals,
       resources: core.resources,
       close: core.close,
-      memoryUsage: core.memoryUsage,
       ...denoNs,
     };
     ObjectDefineProperties(finalDenoNs, {
@@ -665,6 +663,7 @@ delete Object.prototype.__proto__;
       cpuCount,
     } = runtimeOptions;
 
+    colors.setNoColor(noColor);
     location.setLocationHref(locationHref);
     numCpus = cpuCount;
     registerErrors();
