@@ -1,4 +1,4 @@
-// Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
+// Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
 use super::utils::into_string;
 use crate::permissions::Permissions;
@@ -17,15 +17,17 @@ use std::sync::Arc;
 pub fn init(maybe_exit_code: Option<Arc<AtomicI32>>) -> Extension {
   Extension::builder()
     .ops(vec![
-      ("op_exit", op_sync(op_exit)),
       ("op_env", op_sync(op_env)),
       ("op_exec_path", op_sync(op_exec_path)),
-      ("op_set_env", op_sync(op_set_env)),
-      ("op_get_env", op_sync(op_get_env)),
+      ("op_exit", op_sync(op_exit)),
       ("op_delete_env", op_sync(op_delete_env)),
+      ("op_get_env", op_sync(op_get_env)),
+      ("op_getuid", op_sync(op_getuid)),
       ("op_hostname", op_sync(op_hostname)),
       ("op_loadavg", op_sync(op_loadavg)),
+      ("op_network_interfaces", op_sync(op_network_interfaces)),
       ("op_os_release", op_sync(op_os_release)),
+      ("op_set_env", op_sync(op_set_env)),
       ("op_set_exit_code", op_sync(op_set_exit_code)),
       ("op_system_memory_info", op_sync(op_system_memory_info)),
     ])
@@ -149,6 +151,60 @@ fn op_os_release(
   Ok(release)
 }
 
+fn op_network_interfaces(
+  state: &mut OpState,
+  _: (),
+  _: (),
+) -> Result<Vec<NetworkInterface>, AnyError> {
+  super::check_unstable(state, "Deno.networkInterfaces");
+  state.borrow_mut::<Permissions>().env.check_all()?;
+  Ok(netif::up()?.map(NetworkInterface::from).collect())
+}
+
+#[derive(serde::Serialize)]
+struct NetworkInterface {
+  family: &'static str,
+  name: String,
+  address: String,
+  netmask: String,
+  scopeid: Option<u32>,
+  cidr: String,
+  mac: String,
+}
+
+impl From<netif::Interface> for NetworkInterface {
+  fn from(ifa: netif::Interface) -> Self {
+    let family = match ifa.address() {
+      std::net::IpAddr::V4(_) => "IPv4",
+      std::net::IpAddr::V6(_) => "IPv6",
+    };
+
+    let (address, range) = ifa.cidr();
+    let cidr = format!("{:?}/{}", address, range);
+
+    let name = ifa.name().to_owned();
+    let address = format!("{:?}", ifa.address());
+    let netmask = format!("{:?}", ifa.netmask());
+    let scopeid = ifa.scope_id();
+
+    let [b0, b1, b2, b3, b4, b5] = ifa.mac();
+    let mac = format!(
+      "{:02x}:{:02x}:{:02x}:{:02x}:{:02x}:{:02x}",
+      b0, b1, b2, b3, b4, b5
+    );
+
+    Self {
+      family,
+      name,
+      address,
+      netmask,
+      scopeid,
+      cidr,
+      mac,
+    }
+  }
+}
+
 // Copied from sys-info/lib.rs (then tweaked)
 #[derive(Serialize)]
 #[serde(rename_all = "camelCase")]
@@ -182,3 +238,25 @@ fn op_system_memory_info(
     Err(_) => Ok(None),
   }
 }
+
+#[cfg(not(windows))]
+fn op_getuid(
+  state: &mut OpState,
+  _: (),
+  _: (),
+) -> Result<Option<u32>, AnyError> {
+  super::check_unstable(state, "Deno.getUid");
+  state.borrow_mut::<Permissions>().env.check_all()?;
+  unsafe { Ok(Some(libc::getuid())) }
+}
+
+#[cfg(windows)]
+fn op_getuid(
+  state: &mut OpState,
+  _: (),
+  _: (),
+) -> Result<Option<u32>, AnyError> {
+  super::check_unstable(state, "Deno.getUid");
+  state.borrow_mut::<Permissions>().env.check_all()?;
+  Ok(None)
+}
